/*-------------------------------------------------------------------------
# Author: Federico Guerra
# Date: 4 July 2007
# Department of Information Engineering (DEI), University of Padova
#-------------------------------------------------------------------------
#
# Copyright (c) 2007 Regents of the SIGNET lab, University of Padova.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. Neither the name of the University of Padova (SIGNET lab) nor the 
#    names of its contributors may be used to endorse or promote products 
#    derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED 
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR 
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.*/



#include "cnv-module.h"


class ConversationTracer : public Tracer
{
 public:
  ConversationTracer();
 protected:
  void format(Packet *p, SAP* sap);
};



ConversationTracer::ConversationTracer() : Tracer(4) {}



void ConversationTracer::format(Packet *p, SAP *sap)
{
  hdr_cmn *ch = hdr_cmn::access(p);
   
  if (ch->ptype() != PT_CNV)
    return;

  hdr_conversation *cnvh = HDR_CNV(p);

  if (cnvh->rftt_valid)
    {      
      writeTrace(sap, " SN=%d TS=%f RFTT=%f",
		 cnvh->sn,
		 cnvh->ts,
		 cnvh->rftt);
    }
  else
    {      
      writeTrace(sap, " SN=%d TS=%f",
		 cnvh->sn,
		 cnvh->ts);
    }
}

extern "C" int Cnvtracer_Init()
{  
  SAP::addTracer(new ConversationTracer);
  return 0;
}
